==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ru/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Подвердите массовое удаление активов',
  'bulk_delete_help'	=> 'Просмотрите активны, выбранные для удаления. После удаления активы могут быть восстановлены, но уже не будет привязаны к пользователям, к которым они привязаны сейчас.',
  'bulk_delete_warn'	=> 'Вы собираетесь удалить :asset_count активов.',
	'bulk_update'		=> 'Редактировать выбранное',
	'bulk_update_help'	=> 'Эта форма позволяет Вам обновить несколько объектов за раз. Заполняйте только те поля, которые нужно изменить. Пустые поля останутся без изменений. ',
	'bulk_update_warn'	=> 'Редактирование свойств :asset_count assets.',
    'checkedout_to'		=> 'Привязан к',
    'checkout_date'		=> 'Дата выдачи',
    'checkin_date'		=> 'Дата возврата',
    'checkout_to'		=> 'Привязать к',
    'cost'				=> 'Цена',
    'create'			=> 'Создать актив',
    'date'				=> 'Дата покупки',
    'depreciation'	    => 'обесценивание',
    'depreciates_on'	=> 'Обесценивается на',
    'default_location'	=> 'Текущее расположение',
    'eol_date'			=> 'Срок эксплуатации',
    'eol_rate'			=> 'EOL величина',
    'expected_checkin'  => 'Ожидаемая дата возврата',
    'expires'			=> 'Истекает',
    'fully_depreciated'	=> 'Полностью изношен',
    'help_checkout'		=> 'Если вы хотите привязать этот актив немедленно, выберите статус "Готов к установке" из списка ниже. ',
    'mac_address'		=> 'MAC Адрес',
    'manufacturer'		=> 'Производитель',
    'model'				=> 'Модель',
    'months'			=> 'Месяцев',
    'name'				=> 'Имя актива',
    'notes'				=> 'Примечания',
    'order'				=> 'Номер заказа',
    'qr'				=> 'QR-код',
    'requestable'		=> 'Пользователи могут запросить этот актив',
    'select_statustype'	=> 'Выберите тип статуса',
    'serial'			=> 'Серийный номер',
    'status'			=> 'Статус',
    'tag'				=> 'Тег актива',
    'update'			=> 'Изменить актив',
    'warranty'			=> 'Гарантия',
		'warranty_expires'		=> 'Срок действия гарантии',
    'years'				=> 'Лет',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ru/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Подвердите массовое удаление активов',
  'bulk_delete_help'	=> 'Просмотрите активны, выбранные для удаления. После удаления активы могут быть восстановлены, но уже не будет привязаны к пользователям, к которым они привязаны сейчас.',
  'bulk_delete_warn'	=> 'Вы собираетесь удалить :asset_count активов.',
    'bulk_update'		=> 'Редактировать выбранное',
    'bulk_update_help'	=> 'Эта форма позволяет Вам обновить несколько объектов за раз. Заполняйте только те поля, которые нужно изменить. Пустые поля останутся без изменений. ',
    'bulk_update_warn'	=> 'Редактирование свойств :asset_count assets.',
    'checkedout_to'		=> 'Привязан к',
    'checkout_date'		=> 'Дата выдачи',
    'checkin_date'		=> 'Дата возврата',
    'checkout_to'		=> 'Привязать к',
    'cost'				=> 'Цена',
    'create'			=> 'Создать актив',
    'date'				=> 'Дата покупки',
    'depreciation'	    => 'обесценивание',
    'depreciates_on'	=> 'Обесценивается на',
    'default_location'	=> 'Текущее расположение',
    'eol_date'			=> 'Срок эксплуатации',
    'eol_rate'			=> 'EOL величина',
    'expected_checkin'  => 'Ожидаемая дата возврата',
    'expires'			=> 'Истекает',
    'fully_depreciated'	=> 'Полностью изношен',
    'help_checkout'		=> 'Если вы хотите привязать этот актив немедленно, выберите статус "Готов к установке" из списка ниже. ',
    'mac_address'		=> 'MAC Адрес',
    'manufacturer'		=> 'Производитель',
    'model'				=> 'Модель',
    'months'			=> 'Месяцев',
    'name'				=> 'Имя актива',
    'notes'				=> 'Примечания',
    'order'				=> 'Номер заказа',
    'qr'				=> 'QR-код',
    'requestable'		=> 'Пользователи могут запросить этот актив',
    'select_statustype'	=> 'Выберите тип статуса',
    'serial'			=> 'Серийный номер',
    'status'			=> 'Статус',
    'tag'				=> 'Тег актива',
    'update'			=> 'Изменить актив',
    'warranty'			=> 'Гарантия',
        'warranty_expires'		=> 'Срок действия гарантии',
    'years'				=> 'Лет',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
